@@ -52,7 +52,7 @@ Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
 
 =cut
 
-# $Id: docbook2man-spec.pl,v 1.4 2002/04/15 16:32:33 twaugh Exp $
+# $Id: docbook2man-spec.pl,v 1.6 2002/05/16 08:44:23 twaugh Exp $
 
 use SGMLS;			# Use the SGMLS package.
 use SGMLS::Output;		# Use stack-based output.
@@ -1003,6 +1003,8 @@ sgml('<ORDEREDLIST>', sub {
 	$_[0]->ext->{'count'} = 1;
 });
 sgml('</ORDEREDLIST>', \&indent_list_end);
+sgml('<GLOSSLIST>', \&indent_list_start);
+sgml('</GLOSSLIST>', \&indent_list_end);
 		
 # Output content on one line, bolded.
 sgml('<TERM>', sub { 
@@ -1019,6 +1021,20 @@ sgml('</TERM>', sub {
 	output "\n";
 	$newline_last = 1;
 });
+sgml('<GLOSSTERM>', sub { 
+	output "\n" unless $newline_last++;
+	output ".TP\n";
+	bold_on();
+	push_output('string');
+});
+sgml('</GLOSSTERM>', sub { 
+	my $term = pop_output();
+	$term =~ tr/\n/ /;
+	output $term;
+	font_off();
+	output "\n";
+	$newline_last = 1;
+});
 	
 sgml('<LISTITEM>', sub {
 	# A bulleted list.
@@ -1036,6 +1052,9 @@ sgml('<LISTITEM>', sub {
 	
 	$_[0]->ext->{'nobreak'} = 1;
 });
+sgml('<GLOSSDEF>', sub {
+	$_[0]->ext->{'nobreak'} = 1;
+});
 
 sgml('<SIMPLELIST>', sub {
 	$_[0]->ext->{'first_member'} = 1;
@@ -1196,6 +1215,7 @@ sgml('re', sub
 sgml('sdata',sub
 {
 	if($_[0] =~ /\[minus \]/) { output "-"; }
+	elsif($_[0] =~ /\[copy  \]/) { output "(C)"; }
 	else { die "Unknown SDATA: " . $_[0]; }
 });
 sgml('pi',sub { die "Unknown processing instruction: " . $_[0]; });
